@@ -127,7 +127,7 @@ func (o *deleteEnvOpts) Ask() error {
 	if o.skipConfirmation {
 		return nil
 	}
-	deleteConfirmed, err := o.prompt.Confirm(fmt.Sprintf(fmtDeleteEnvPrompt, o.name, o.appName), "")
+	deleteConfirmed, err := o.prompt.Confirm(fmt.Sprintf(fmtDeleteEnvPrompt, o.name, o.appName), "", prompt.WithConfirmFinalMessage())
 	if err != nil {
 		return fmt.Errorf("confirm to delete environment %s: %w", o.name, err)
 	}
@@ -173,8 +173,8 @@ func (o *deleteEnvOpts) Execute() error {
 	return nil
 }
 
-// RecommendedActions is a no-op for this command.
-func (o *deleteEnvOpts) RecommendedActions() []string {
+// RecommendActions is a no-op for this command.
+func (o *deleteEnvOpts) RecommendActions() error {
 	return nil
 }
 
@@ -386,13 +386,7 @@ func buildEnvDeleteCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			if err := opts.Validate(); err != nil {
-				return err
-			}
-			if err := opts.Ask(); err != nil {
-				return err
-			}
-			return opts.Execute()
+			return run(opts)
 		}),
 	}
 	cmd.Flags().StringVarP(&vars.appName, appFlag, appFlagShort, tryReadingAppName(), appFlagDescription)
