@@ -187,8 +187,8 @@ func (o *envUpgradeOpts) Execute() error {
 	return nil
 }
 
-// RecommendedActions is a no-op for this command.
-func (o *envUpgradeOpts) RecommendedActions() []string {
+// RecommendActions is a no-op for this command.
+func (o *envUpgradeOpts) RecommendActions() error {
 	return nil
 }
 
@@ -385,13 +385,7 @@ func buildEnvUpgradeCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			if err := opts.Validate(); err != nil {
-				return err
-			}
-			if err := opts.Ask(); err != nil {
-				return err
-			}
-			return opts.Execute()
+			return run(opts)
 		}),
 	}
 	cmd.Flags().StringVarP(&vars.name, nameFlag, nameFlagShort, "", envFlagDescription)
