@@ -8,8 +8,11 @@ import (
 	"fmt"
 	"strconv"
 
+	"github.com/aws/copilot-cli/internal/pkg/docker/dockerengine"
+
 	"github.com/aws/copilot-cli/internal/pkg/aws/sessions"
 	"github.com/aws/copilot-cli/internal/pkg/config"
+	"github.com/aws/copilot-cli/internal/pkg/deploy"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/exec"
 	"github.com/aws/copilot-cli/internal/pkg/initialize"
@@ -37,15 +40,23 @@ const (
 )
 
 var (
-	fmtSvcInitSvcTypePrompt     = "Which %s best represents your service's architecture?"
-	fmtSvcInitSvcTypeHelpPrompt = `A %s is an internet-facing HTTP server managed by AWS App Runner that scales based on incoming requests.
-To learn more see: https://git.io/Jt2UC
+	fmtSvcInitSvcTypePrompt  = "Which %s best represents your service's architecture?"
+	svcInitSvcTypeHelpPrompt = fmt.Sprintf(`A %s is an internet-facing HTTP server managed by AWS App Runner that scales based on incoming requests.
+To learn more see: https://git.io/JEEfb
 
 A %s is an internet-facing HTTP server managed by Amazon ECS on AWS Fargate behind a load balancer.
-To learn more see: https://git.io/JfIpv
+To learn more see: https://git.io/JEEJe
 
 A %s is a private, non internet-facing service accessible from other services in your VPC.
-To learn more see: https://git.io/JfIpT`
+To learn more see: https://git.io/JEEJt
+
+A %s is a private service that can consume messages published to topics in your application.
+To learn more see: https://git.io/JEEJY`,
+		manifest.RequestDrivenWebServiceType,
+		manifest.LoadBalancedWebServiceType,
+		manifest.BackendServiceType,
+		manifest.WorkerServiceType,
+	)
 
 	fmtWkldInitNamePrompt     = "What do you want to %s this %s?"
 	fmtWkldInitNameHelpPrompt = `The name will uniquely identify this %s within your app %s.
@@ -59,12 +70,17 @@ Deployed resources (such as your ECR repository, logs) will contain this %[1]s's
 	svcInitSvcPortPrompt     = "Which %s do you want customer traffic sent to?"
 	svcInitSvcPortHelpPrompt = `The port will be used by the load balancer to route incoming traffic to this service.
 You should set this to the port which your Dockerfile uses to communicate with the internet.`
+
+	svcInitPublisherPrompt     = "Which topics do you want to subscribe to?"
+	svcInitPublisherHelpPrompt = `A publisher is an existing SNS Topic to which a service publishes messages. 
+These messages can be consumed by the Worker Service.`
 )
 
 var serviceTypeHints = map[string]string{
 	manifest.RequestDrivenWebServiceType: "App Runner",
 	manifest.LoadBalancedWebServiceType:  "Internet to ECS on Fargate",
 	manifest.BackendServiceType:          "ECS on Fargate",
+	manifest.WorkerServiceType:           "Events to SQS to ECS on Fargate",
 }
 
 type initWkldVars struct {
@@ -73,6 +89,8 @@ type initWkldVars struct {
 	name           string
 	dockerfilePath string
 	image          string
+	subscriptions  []string
+	noSubscribe    bool
 }
 
 type initSvcVars struct {
@@ -90,10 +108,12 @@ type initSvcOpts struct {
 	prompt       prompter
 	dockerEngine dockerEngine
 	sel          dockerfileSelector
+	topicSel     topicSelector
 
 	// Outputs stored on successful actions.
 	manifestPath string
 	platform     *string
+	topics       []manifest.TopicSubscription
 
 	// Cache variables
 	df dockerfileParser
@@ -120,6 +140,11 @@ func newInitSvcOpts(vars initSvcVars) (*initSvcOpts, error) {
 	}
 	prompter := prompt.New()
 	sel := selector.NewWorkspaceSelect(prompter, store, ws)
+	deployStore, err := deploy.NewStore(store)
+	if err != nil {
+		return nil, err
+	}
+	snsSel := selector.NewDeploySelect(prompter, store, deployStore)
 
 	initSvc := &initialize.WorkloadInitializer{
 		Store:    store,
@@ -135,7 +160,8 @@ func newInitSvcOpts(vars initSvcVars) (*initSvcOpts, error) {
 		init:         initSvc,
 		prompt:       prompter,
 		sel:          sel,
-		dockerEngine: exec.NewDockerCommand(),
+		topicSel:     snsSel,
+		dockerEngine: dockerengine.New(exec.NewCmd()),
 	}
 	opts.dockerfile = func(path string) dockerfileParser {
 		if opts.df != nil {
@@ -180,6 +206,9 @@ func (o *initSvcOpts) Validate() error {
 			return err
 		}
 	}
+	if err := validateSubscribe(o.noSubscribe, o.subscriptions); err != nil {
+		return err
+	}
 	return nil
 }
 
@@ -206,6 +235,10 @@ func (o *initSvcOpts) Ask() error {
 		return err
 	}
 
+	if err := o.askSvcPublishers(); err != nil {
+		return err
+	}
+
 	return nil
 }
 
@@ -226,6 +259,12 @@ func (o *initSvcOpts) Execute() error {
 		return fmt.Errorf("get/redirect docker engine platform: %w", err)
 	}
 	o.platform = platform
+	if o.platform != nil {
+		log.Warningf(`Your architecture type is currently unsupported. Setting platform %s instead.\n`, dockerengine.DockerBuildPlatform(dockerengine.LinuxOS, dockerengine.Amd64Arch))
+		if o.wkldType != manifest.RequestDrivenWebServiceType {
+			log.Warning("See 'platform' field in your manifest.\n")
+		}
+	}
 
 	manifestPath, err := o.init.Service(&initialize.ServiceProps{
 		WorkloadProps: initialize.WorkloadProps{
@@ -235,6 +274,7 @@ func (o *initSvcOpts) Execute() error {
 			DockerfilePath: o.dockerfilePath,
 			Image:          o.image,
 			Platform:       o.platform,
+			Topics:         o.topics,
 		},
 		Port:        o.port,
 		HealthCheck: hc,
@@ -246,14 +286,15 @@ func (o *initSvcOpts) Execute() error {
 	return nil
 }
 
-// RecommendedActions returns follow-up actions the user can take after successfully executing the command.
-func (o *initSvcOpts) RecommendedActions() []string {
-	return []string{
+// RecommendActions returns follow-up actions the user can take after successfully executing the command.
+func (o *initSvcOpts) RecommendActions() error {
+	logRecommendedActions([]string{
 		fmt.Sprintf("Update your manifest %s to change the defaults.", color.HighlightResource(o.manifestPath)),
 		fmt.Sprintf("Run %s to deploy your service to a %s environment.",
 			color.HighlightCode(fmt.Sprintf("copilot svc deploy --name %s --env %s", o.name, defaultEnvironmentName)),
 			defaultEnvironmentName),
-	}
+	})
+	return nil
 }
 
 func (o *initSvcOpts) askSvcType() error {
@@ -261,14 +302,8 @@ func (o *initSvcOpts) askSvcType() error {
 		return nil
 	}
 
-	help := fmt.Sprintf(fmtSvcInitSvcTypeHelpPrompt,
-		manifest.RequestDrivenWebServiceType,
-		manifest.LoadBalancedWebServiceType,
-		manifest.BackendServiceType,
-	)
 	msg := fmt.Sprintf(fmtSvcInitSvcTypePrompt, color.Emphasize("service type"))
-
-	t, err := o.prompt.SelectOption(msg, help, svcTypePromptOpts(), prompt.WithFinalMessage("Service type:"))
+	t, err := o.prompt.SelectOption(msg, svcInitSvcTypeHelpPrompt, svcTypePromptOpts(), prompt.WithFinalMessage("Service type:"))
 	if err != nil {
 		return fmt.Errorf("select service type: %w", err)
 	}
@@ -326,9 +361,9 @@ func (o *initSvcOpts) askDockerfile() (isDfSelected bool, err error) {
 		return true, nil
 	}
 	if err = o.dockerEngine.CheckDockerEngineRunning(); err != nil {
-		var errDaemon *exec.ErrDockerDaemonNotResponsive
+		var errDaemon *dockerengine.ErrDockerDaemonNotResponsive
 		switch {
-		case errors.Is(err, exec.ErrDockerCommandNotFound):
+		case errors.Is(err, dockerengine.ErrDockerCommandNotFound):
 			log.Info("Docker command is not found; Copilot won't build from a Dockerfile.\n")
 			return false, nil
 		case errors.As(err, &errDaemon):
@@ -385,8 +420,8 @@ func (o *initSvcOpts) askSvcPort() (err error) {
 			defaultPort = strconv.Itoa(int(ports[0]))
 		}
 	}
-	// Skip asking if it is a backend service.
-	if o.wkldType == manifest.BackendServiceType {
+	// Skip asking if it is a backend or worker service.
+	if o.wkldType == manifest.BackendServiceType || o.wkldType == manifest.WorkerServiceType {
 		return nil
 	}
 
@@ -411,6 +446,58 @@ func (o *initSvcOpts) askSvcPort() (err error) {
 	return nil
 }
 
+func (o *initSvcOpts) askSvcPublishers() (err error) {
+	if o.wkldType != manifest.WorkerServiceType {
+		return nil
+	}
+	// publishers already specified by flags
+	if len(o.subscriptions) > 0 {
+		var topicSubscriptions []manifest.TopicSubscription
+		for _, sub := range o.subscriptions {
+			sub, err := parseSerializedSubscription(sub)
+			if err != nil {
+				return err
+			}
+			topicSubscriptions = append(topicSubscriptions, sub)
+		}
+		o.topics = topicSubscriptions
+		return nil
+	}
+
+	// if --no-subscriptions flag specified, no need to ask for publishers
+	if o.noSubscribe {
+		return nil
+	}
+
+	topics, err := o.topicSel.Topics(svcInitPublisherPrompt, svcInitPublisherHelpPrompt, o.appName)
+	if err != nil {
+		return fmt.Errorf("select publisher: %w", err)
+	}
+
+	subscriptions := make([]manifest.TopicSubscription, 0, len(topics))
+	for _, t := range topics {
+		subscriptions = append(subscriptions, manifest.TopicSubscription{
+			Name:    t.Name(),
+			Service: t.Workload(),
+		})
+	}
+	o.topics = subscriptions
+
+	return nil
+}
+
+// parseSerializedSubscription parses the service and topic name out of keys specified in the form "service:topicName"
+func parseSerializedSubscription(input string) (manifest.TopicSubscription, error) {
+	attrs := regexpMatchSubscription.FindStringSubmatch(input)
+	if len(attrs) == 0 {
+		return manifest.TopicSubscription{}, fmt.Errorf("parse subscription from key: %s", input)
+	}
+	return manifest.TopicSubscription{
+		Name:    attrs[2],
+		Service: attrs[1],
+	}, nil
+}
+
 func parseHealthCheck(df dockerfileParser) (*manifest.ContainerHealthCheck, error) {
 	hc, err := df.GetHealthCheck()
 	if err != nil {
@@ -468,9 +555,8 @@ This command is also run as part of "copilot init".`,
 			if err := opts.Execute(); err != nil {
 				return err
 			}
-			log.Infoln("Recommended follow-up actions:")
-			for _, followup := range opts.RecommendedActions() {
-				log.Infof("- %s\n", followup)
+			if err := opts.RecommendActions(); err != nil {
+				return err
 			}
 			return nil
 		}),
@@ -481,5 +567,8 @@ This command is also run as part of "copilot init".`,
 	cmd.Flags().StringVarP(&vars.dockerfilePath, dockerFileFlag, dockerFileFlagShort, "", dockerFileFlagDescription)
 	cmd.Flags().StringVarP(&vars.image, imageFlag, imageFlagShort, "", imageFlagDescription)
 	cmd.Flags().Uint16Var(&vars.port, svcPortFlag, 0, svcPortFlagDescription)
+	cmd.Flags().StringArrayVar(&vars.subscriptions, subscribeTopicsFlag, []string{}, subscribeTopicsFlagDescription)
+	cmd.Flags().BoolVar(&vars.noSubscribe, noSubscriptionFlag, false, noSubscriptionFlagDescription)
+
 	return cmd
 }
