@@ -75,6 +75,7 @@ type packageSvcOpts struct {
 	identity          identityService
 	stackSerializer   func(mft interface{}, env *config.Environment, app *config.Application, rc stack.RuntimeConfig) (stackSerializer, error)
 	newEndpointGetter func(app, env string) (endpointGetter, error)
+	snsTopicGetter    deployedEnvironmentLister
 }
 
 func newPackageSvcOpts(vars packageSvcVars) (*packageSvcOpts, error) {
@@ -86,6 +87,10 @@ func newPackageSvcOpts(vars packageSvcVars) (*packageSvcOpts, error) {
 	if err != nil {
 		return nil, fmt.Errorf("connect to config store: %w", err)
 	}
+	deployStore, err := deploy.NewStore(store)
+	if err != nil {
+		return nil, fmt.Errorf("new deploy store: %w", err)
+	}
 	p := sessions.NewProvider()
 	sess, err := p.Default()
 	if err != nil {
@@ -106,6 +111,7 @@ func newPackageSvcOpts(vars packageSvcVars) (*packageSvcOpts, error) {
 		paramsWriter:     ioutil.Discard,
 		addonsWriter:     ioutil.Discard,
 		fs:               &afero.Afero{Fs: afero.NewOsFs()},
+		snsTopicGetter:   deployStore,
 	}
 	appVersionGetter, err := describe.NewAppDescriber(vars.appName)
 	if err != nil {
@@ -116,7 +122,7 @@ func newPackageSvcOpts(vars packageSvcVars) (*packageSvcOpts, error) {
 		switch t := mft.(type) {
 		case *manifest.LoadBalancedWebService:
 			if app.RequiresDNSDelegation() {
-				if err := validateAliasAndAppVersion(aws.StringValue(t.Name), aws.StringValue(t.Alias), app, env.Name, appVersionGetter); err != nil {
+				if err := validateLBSvcAliasAndAppVersion(aws.StringValue(t.Name), t.Alias, app, env.Name, appVersionGetter); err != nil {
 					return nil, err
 				}
 				serializer, err = stack.NewHTTPSLoadBalancedWebService(t, env.Name, app.Name, rc)
@@ -179,6 +185,33 @@ func newPackageSvcOpts(vars packageSvcVars) (*packageSvcOpts, error) {
 			if err != nil {
 				return nil, fmt.Errorf("init backend service stack serializer: %w", err)
 			}
+		case *manifest.WorkerService:
+			var topics []deploy.Topic
+			topics, err = opts.snsTopicGetter.ListSNSTopics(opts.appName, opts.envName)
+			if err != nil {
+				return nil, err
+			}
+			var topicARNs []string
+			for _, topic := range topics {
+				topicARNs = append(topicARNs, topic.ARN())
+			}
+			type subscriptions interface {
+				Subscriptions() []manifest.TopicSubscription
+			}
+
+			subscriptionGetter, ok := mft.(subscriptions)
+			if !ok {
+				return nil, errors.New("manifest does not have required method Subscriptions")
+			}
+			// Cache the subscriptions for later.
+			topicSubs := subscriptionGetter.Subscriptions()
+			if err = validateTopicsExist(topicSubs, topicARNs, app.Name, env.Name); err != nil {
+				return nil, err
+			}
+			serializer, err = stack.NewWorkerService(t, env.Name, app.Name, rc)
+			if err != nil {
+				return nil, fmt.Errorf("init worker service stack serializer: %w", err)
+			}
 		default:
 			return nil, fmt.Errorf("create stack serializer for manifest of type %T", t)
 		}
@@ -422,8 +455,8 @@ func (o *packageSvcOpts) setAddonsFileWriter() error {
 	return nil
 }
 
-// RecommendedActions is a no-op for this command.
-func (o *packageSvcOpts) RecommendedActions() []string {
+// RecommendActions is a no-op for this command.
+func (o *packageSvcOpts) RecommendActions() error {
 	return nil
 }
 
@@ -476,14 +509,7 @@ func buildSvcPackageCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-
-			if err := opts.Validate(); err != nil {
-				return err
-			}
-			if err := opts.Ask(); err != nil {
-				return err
-			}
-			return opts.Execute()
+			return run(opts)
 		}),
 	}
 	cmd.Flags().StringVarP(&vars.name, nameFlag, nameFlagShort, "", svcFlagDescription)
