@@ -261,7 +261,8 @@ func (o *deleteTaskOpts) Ask() error {
 
 	deleteConfirmed, err := o.prompt.Confirm(
 		deletePrompt,
-		taskDeleteConfirmHelp)
+		taskDeleteConfirmHelp,
+		prompt.WithConfirmFinalMessage())
 
 	if err != nil {
 		return fmt.Errorf("task delete confirmation prompt: %w", err)
@@ -442,7 +443,7 @@ func (o *deleteTaskOpts) deleteStack() error {
 	return nil
 }
 
-func (o *deleteTaskOpts) RecommendedActions() []string {
+func (o *deleteTaskOpts) RecommendActions() error {
 	return nil
 }
 
@@ -466,25 +467,7 @@ func BuildTaskDeleteCmd() *cobra.Command {
 			if err != nil {
 				return err
 			}
-			if err := opts.Validate(); err != nil {
-				return err
-			}
-			if err := opts.Ask(); err != nil {
-				return err
-			}
-			if err := opts.Execute(); err != nil {
-				return err
-			}
-
-			if len(opts.RecommendedActions()) == 0 {
-				return nil
-			}
-
-			log.Infoln("Recommended follow-up actions:")
-			for _, followup := range opts.RecommendedActions() {
-				log.Infof("- %s\n", followup)
-			}
-			return nil
+			return run(opts)
 		}),
 	}
 
