@@ -7,10 +7,12 @@ import (
 	"errors"
 	"fmt"
 	"hash/crc32"
+	"regexp"
 	"strings"
 	"time"
 
 	"github.com/aws/copilot-cli/internal/pkg/deploy"
+	"github.com/aws/copilot-cli/internal/pkg/template/override"
 
 	"github.com/aws/copilot-cli/internal/pkg/aws/s3"
 
@@ -58,6 +60,9 @@ const (
 var (
 	errEphemeralBadSize  = errors.New("ephemeral storage must be between 20 GiB and 200 GiB")
 	errInvalidSpotConfig = errors.New(`"count.spot" and "count.range" cannot be specified together`)
+
+	taskDefOverrideRulePrefixes      = []string{"Resources", "TaskDefinition", "Properties"}
+	invalidTaskDefOverridePathRegexp = []string{`Family`, `ContainerDefinitions\[\d+\].Name`}
 )
 
 type convertSidecarOpts struct {
@@ -330,6 +335,31 @@ func logConfigOpts(lc *manifest.Logging) *template.LogConfigOpts {
 	}
 }
 
+func convertTaskDefOverrideRules(inRules []manifest.OverrideRule) []override.Rule {
+	var res []override.Rule
+	suffixStr := strings.Join(taskDefOverrideRulePrefixes, override.PathSegmentSeparator)
+	for _, r := range inRules {
+		if !isValidTaskDefOverridePath(r.Path) {
+			continue
+		}
+		res = append(res, override.Rule{
+			Path:  strings.Join([]string{suffixStr, r.Path}, override.PathSegmentSeparator),
+			Value: r.Value,
+		})
+	}
+	return res
+}
+
+func isValidTaskDefOverridePath(path string) bool {
+	for _, s := range invalidTaskDefOverridePathRegexp {
+		re := regexp.MustCompile(fmt.Sprintf(`^%s$`, s))
+		if re.MatchString(path) {
+			return false
+		}
+	}
+	return true
+}
+
 // convertStorageOpts converts a manifest Storage field into template data structures which can be used
 // to execute CFN templates
 func convertStorageOpts(wlName *string, in *manifest.Storage) (*template.StorageOpts, error) {
@@ -578,6 +608,18 @@ func convertNetworkConfig(network *manifest.NetworkConfig) *template.NetworkOpts
 	return opts
 }
 
+func convertAlias(alias *manifest.Alias) ([]string, error) {
+	if alias == nil {
+		return nil, nil
+	}
+
+	out, err := alias.ToStringSlice()
+	if err != nil {
+		return nil, fmt.Errorf(`convert 'http.alias' to string slice: %w`, err)
+	}
+	return out, nil
+}
+
 func convertEntryPoint(entrypoint *manifest.EntryPointOverride) ([]string, error) {
 	if entrypoint == nil {
 		return nil, nil
@@ -601,8 +643,8 @@ func convertCommand(command *manifest.CommandOverride) ([]string, error) {
 	return out, nil
 }
 
-func convertPublish(p *manifest.PublishConfig, accountID, region, app, env, svc string) (*template.PublishOpts, error) {
-	if p == nil || len(p.Topics) == 0 {
+func convertPublish(topics []manifest.Topic, accountID, region, app, env, svc string) (*template.PublishOpts, error) {
+	if len(topics) == 0 {
 		return nil, nil
 	}
 	partition, ok := endpoints.PartitionForRegion(endpoints.DefaultPartitions(), region)
@@ -611,7 +653,7 @@ func convertPublish(p *manifest.PublishConfig, accountID, region, app, env, svc
 	}
 	var publishers template.PublishOpts
 	// convert the topics to template Topics
-	for _, topic := range p.Topics {
+	for _, topic := range topics {
 		t, err := convertTopic(topic, accountID, partition.ID(), region, app, env, svc)
 		if err != nil {
 			return nil, err
@@ -655,8 +697,8 @@ func convertSubscribe(s *manifest.SubscribeConfig, validTopicARNs []string, acco
 	}
 
 	var subscriptions template.SubscribeOpts
-	for _, sb := range *s.Topics {
-		ts, err := convertTopicSubscription(sb, validTopicARNs, sqsEndpoint.URL, accountID, app, env, svc)
+	for _, sb := range s.Topics {
+		ts, err := convertTopicSubscription(sb, sqsEndpoint.URL, accountID, app, env, svc)
 		if err != nil {
 			return nil, err
 		}
@@ -672,8 +714,8 @@ func convertSubscribe(s *manifest.SubscribeConfig, validTopicARNs []string, acco
 	return &subscriptions, nil
 }
 
-func convertTopicSubscription(t manifest.TopicSubscription, validTopicARNs []string, url, accountID, app, env, svc string) (*template.TopicSubscription, error) {
-	err := validateTopicSubscription(t, validTopicARNs, app, env)
+func convertTopicSubscription(t manifest.TopicSubscription, url, accountID, app, env, svc string) (*template.TopicSubscription, error) {
+	err := validateTopicSubscription(t)
 	if err != nil {
 		return nil, fmt.Errorf(`invalid topic subscription "%s": %w`, t.Name, err)
 	}
@@ -715,7 +757,6 @@ func convertQueue(q *manifest.SQSQueue, url, accountID, app, env, svc string) (*
 		Delay:      delay,
 		Timeout:    timeout,
 		DeadLetter: deadletter,
-		FIFO:       convertFIFO(q.FIFO),
 	}, nil
 }
 
@@ -743,16 +784,6 @@ func convertTimeout(t *time.Duration) (*int64, error) {
 	return convertTime(t, timeoutMinValueSeconds*time.Second, timeoutMaxValueSeconds*time.Second)
 }
 
-func convertFIFO(f *manifest.FIFOOrBool) *template.FIFOQueue {
-	if f == nil || !aws.BoolValue(f.Enabled) {
-		return nil
-	}
-
-	return &template.FIFOQueue{
-		HighThroughput: aws.BoolValue(f.FIFO.HighThroughput),
-	}
-}
-
 func convertDeadLetter(d *manifest.DeadLetterQueue) (*template.DeadLetterQueue, error) {
 	if d == nil {
 		return nil, nil
