@@ -11,7 +11,9 @@ import (
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/template"
+	"github.com/aws/copilot-cli/internal/pkg/template/override"
 	"github.com/stretchr/testify/require"
+	"gopkg.in/yaml.v3"
 )
 
 func Test_convertSidecar(t *testing.T) {
@@ -545,6 +547,44 @@ func Test_convertAutoscaling(t *testing.T) {
 	}
 }
 
+func Test_convertTaskDefOverrideRules(t *testing.T) {
+	testCases := map[string]struct {
+		inRule []manifest.OverrideRule
+
+		wanted []override.Rule
+	}{
+		"should have proper prefix": {
+			inRule: []manifest.OverrideRule{
+				{
+					Path:  "ContainerDefinitions[0].Ulimits[-].HardLimit",
+					Value: yaml.Node{},
+				},
+				{
+					Path:  "ContainerDefinitions[0].Name",
+					Value: yaml.Node{},
+				},
+				{
+					Path:  "Family",
+					Value: yaml.Node{},
+				},
+			},
+			wanted: []override.Rule{
+				{
+					Path:  "Resources.TaskDefinition.Properties.ContainerDefinitions[0].Ulimits[-].HardLimit",
+					Value: yaml.Node{},
+				},
+			},
+		},
+	}
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			got := convertTaskDefOverrideRules(tc.inRule)
+
+			require.Equal(t, tc.wanted, got)
+		})
+	}
+}
+
 func Test_convertHTTPHealthCheck(t *testing.T) {
 	// These are used by reference to represent the output of the manifest.durationp function.
 	duration15Seconds := 15 * time.Second
@@ -1466,29 +1506,27 @@ func Test_convertPublish(t *testing.T) {
 	env := "testenv"
 	svc := "hello"
 	testCases := map[string]struct {
-		inPublish *manifest.PublishConfig
+		inTopics []manifest.Topic
 
 		wanted      *template.PublishOpts
 		wantedError error
 	}{
-		"empty publish": {
-			inPublish: &manifest.PublishConfig{},
-			wanted:    nil,
+		"no manifest publishers should return nil": {
+			inTopics: nil,
+			wanted:   nil,
+		},
+		"empty manifest publishers should return nil": {
+			inTopics: []manifest.Topic{},
+			wanted:   nil,
 		},
 		"publish with no topic names": {
-			inPublish: &manifest.PublishConfig{
-				Topics: []manifest.Topic{
-					{},
-				},
-			},
+			inTopics:    []manifest.Topic{{}},
 			wantedError: errMissingPublishTopicField,
 		},
 		"publish with no workers": {
-			inPublish: &manifest.PublishConfig{
-				Topics: []manifest.Topic{
-					{
-						Name: aws.String("topic1"),
-					},
+			inTopics: []manifest.Topic{
+				{
+					Name: aws.String("topic1"),
 				},
 			},
 			wanted: &template.PublishOpts{
@@ -1506,12 +1544,10 @@ func Test_convertPublish(t *testing.T) {
 			},
 		},
 		"publish with workers": {
-			inPublish: &manifest.PublishConfig{
-				Topics: []manifest.Topic{
-					{
-						Name:           aws.String("topic1"),
-						AllowedWorkers: []string{"worker1"},
-					},
+			inTopics: []manifest.Topic{
+				{
+					Name:           aws.String("topic1"),
+					AllowedWorkers: []string{"worker1"},
 				},
 			},
 			wanted: &template.PublishOpts{
@@ -1530,23 +1566,19 @@ func Test_convertPublish(t *testing.T) {
 			},
 		},
 		"invalid worker name": {
-			inPublish: &manifest.PublishConfig{
-				Topics: []manifest.Topic{
-					{
-						Name:           aws.String("topic1"),
-						AllowedWorkers: []string{"worker1~~@#$"},
-					},
+			inTopics: []manifest.Topic{
+				{
+					Name:           aws.String("topic1"),
+					AllowedWorkers: []string{"worker1~~@#$"},
 				},
 			},
 			wantedError: fmt.Errorf("worker name `worker1~~@#$` is invalid: %s", errSvcNameBadFormat),
 		},
 		"invalid topic name": {
-			inPublish: &manifest.PublishConfig{
-				Topics: []manifest.Topic{
-					{
-						Name:           aws.String("topic1~~@#$"),
-						AllowedWorkers: []string{"worker1"},
-					},
+			inTopics: []manifest.Topic{
+				{
+					Name:           aws.String("topic1~~@#$"),
+					AllowedWorkers: []string{"worker1"},
 				},
 			},
 			wantedError: errInvalidPubSubTopicName,
@@ -1554,7 +1586,7 @@ func Test_convertPublish(t *testing.T) {
 	}
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
-			got, err := convertPublish(tc.inPublish, accountId, region, app, env, svc)
+			got, err := convertPublish(tc.inTopics, accountId, region, app, env, svc)
 			if tc.wantedError != nil {
 				require.EqualError(t, err, tc.wantedError.Error())
 			} else {
@@ -1585,7 +1617,7 @@ func Test_convertSubscribe(t *testing.T) {
 		},
 		"subscription with empty topic subscriptions": {
 			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
+				Topics: []manifest.TopicSubscription{
 					{},
 				},
 			},
@@ -1593,7 +1625,7 @@ func Test_convertSubscribe(t *testing.T) {
 		},
 		"valid subscribe": {
 			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
+				Topics: []manifest.TopicSubscription{
 					{
 						Name:    "name",
 						Service: "svc",
@@ -1606,12 +1638,6 @@ func Test_convertSubscribe(t *testing.T) {
 					DeadLetter: &manifest.DeadLetterQueue{
 						Tries: aws.Uint16(35),
 					},
-					FIFO: &manifest.FIFOOrBool{
-						Enabled: aws.Bool(true),
-						FIFO: manifest.FIFOQueue{
-							HighThroughput: aws.Bool(false),
-						},
-					},
 				},
 			},
 			wanted: &template.SubscribeOpts{
@@ -1628,15 +1654,12 @@ func Test_convertSubscribe(t *testing.T) {
 					DeadLetter: &template.DeadLetterQueue{
 						Tries: aws.Uint16(35),
 					},
-					FIFO: &template.FIFOQueue{
-						HighThroughput: false,
-					},
 				},
 			},
 		},
 		"valid subscribe with minimal queue": {
 			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
+				Topics: []manifest.TopicSubscription{
 					{
 						Name:    "name",
 						Service: "svc",
@@ -1656,7 +1679,7 @@ func Test_convertSubscribe(t *testing.T) {
 		},
 		"invalid topic name": {
 			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
+				Topics: []manifest.TopicSubscription{
 					{
 						Name:    "t@p!c1~",
 						Service: "service1",
@@ -1667,7 +1690,7 @@ func Test_convertSubscribe(t *testing.T) {
 		},
 		"invalid service name": {
 			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
+				Topics: []manifest.TopicSubscription{
 					{
 						Name:    "topic1",
 						Service: "s#rv!ce1~",
@@ -1676,31 +1699,9 @@ func Test_convertSubscribe(t *testing.T) {
 			},
 			wantedError: fmt.Errorf(`invalid topic subscription "topic1": %w`, errSvcNameBadFormat),
 		},
-		"topic not allowed": {
-			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
-					{
-						Name:    "topic1",
-						Service: "svc",
-					},
-				},
-			},
-			wantedError: fmt.Errorf(`invalid topic subscription "topic1": %w`, errTopicSubscriptionNotAllowed),
-		},
-		"sneaky topic not allowed": {
-			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
-					{
-						Name:    "sneakytopic",
-						Service: "svc-name",
-					},
-				},
-			},
-			wantedError: fmt.Errorf(`invalid topic subscription "sneakytopic": %w`, errTopicSubscriptionNotAllowed),
-		},
 		"subscribe queue delay invalid": {
 			inSubscribe: &manifest.SubscribeConfig{
-				Topics: &[]manifest.TopicSubscription{
+				Topics: []manifest.TopicSubscription{
 					{
 						Name:    "name",
 						Service: "svc",
@@ -1724,59 +1725,3 @@ func Test_convertSubscribe(t *testing.T) {
 		})
 	}
 }
-
-func Test_convertFIFO(t *testing.T) {
-	testCases := map[string]struct {
-		inFIFO *manifest.FIFOOrBool
-
-		wanted      *template.FIFOQueue
-		wantedError error
-	}{
-		"empty FIFO": {
-			inFIFO: &manifest.FIFOOrBool{},
-			wanted: nil,
-		},
-		"FIFO with enabled false": {
-			inFIFO: &manifest.FIFOOrBool{
-				Enabled: aws.Bool(false),
-			},
-			wanted: nil,
-		},
-		"FIFO with enabled true and no high throughput": {
-			inFIFO: &manifest.FIFOOrBool{
-				Enabled: aws.Bool(true),
-			},
-			wanted: &template.FIFOQueue{
-				HighThroughput: false,
-			},
-		},
-		"FIFO with enabled true and high throughput false": {
-			inFIFO: &manifest.FIFOOrBool{
-				Enabled: aws.Bool(true),
-				FIFO: manifest.FIFOQueue{
-					HighThroughput: aws.Bool(false),
-				},
-			},
-			wanted: &template.FIFOQueue{
-				HighThroughput: false,
-			},
-		},
-		"FIFO with enabled true and high throughput true": {
-			inFIFO: &manifest.FIFOOrBool{
-				Enabled: aws.Bool(true),
-				FIFO: manifest.FIFOQueue{
-					HighThroughput: aws.Bool(true),
-				},
-			},
-			wanted: &template.FIFOQueue{
-				HighThroughput: true,
-			},
-		},
-	}
-	for name, tc := range testCases {
-		t.Run(name, func(t *testing.T) {
-			got := convertFIFO(tc.inFIFO)
-			require.Equal(t, tc.wanted, got)
-		})
-	}
-}
