@@ -20,7 +20,6 @@ import (
 	"github.com/aws/copilot-cli/internal/pkg/describe/stack"
 	"github.com/aws/copilot-cli/internal/pkg/manifest"
 	"github.com/aws/copilot-cli/internal/pkg/term/color"
-	"github.com/dustin/go-humanize/english"
 )
 
 const (
@@ -28,41 +27,6 @@ const (
 	envOutputSubdomain                 = "EnvironmentSubdomain"
 )
 
-var fmtSvcDiscoveryEndpointWithPort = "%s.%s:%s" // Format string of the form {svc}.{endpoint}:{port}
-
-// LBWebServiceURI represents the unique identifier to access a load balanced web service.
-type LBWebServiceURI struct {
-	HTTPS    bool
-	DNSNames []string // The environment's subdomain if the service is served on HTTPS. Otherwise, the public load balancer's DNS.
-	Path     string   // Empty if the service is served on HTTPS. Otherwise, the pattern used to match the service.
-}
-
-func (u *LBWebServiceURI) String() string {
-	var uris []string
-	for _, dnsName := range u.DNSNames {
-		protocol := "http://"
-		if u.HTTPS {
-			protocol = "https://"
-		}
-		path := ""
-		if u.Path != "/" {
-			path = fmt.Sprintf("/%s", u.Path)
-		}
-		uris = append(uris, fmt.Sprintf("%s%s%s", protocol, dnsName, path))
-	}
-	return english.OxfordWordSeries(uris, "or")
-}
-
-type serviceDiscovery struct {
-	Service  string
-	Endpoint string
-	Port     string
-}
-
-func (s *serviceDiscovery) String() string {
-	return fmt.Sprintf(fmtSvcDiscoveryEndpointWithPort, s.Service, s.Endpoint, s.Port)
-}
-
 type envDescriber interface {
 	ServiceDiscoveryEndpoint() (string, error)
 	Params() (map[string]string, error)
@@ -71,38 +35,27 @@ type envDescriber interface {
 
 // LBWebServiceDescriber retrieves information about a load balanced web service.
 type LBWebServiceDescriber struct {
-	app             string
-	svc             string
-	enableResources bool
-
-	store         DeployedEnvServicesLister
-	svcDescriber  map[string]ecsSvcDescriber
-	envDescriber  map[string]envDescriber
-	initDescriber func(string) error
+	*ecsServiceDescriber
+	envDescriber map[string]envDescriber
 
 	// cache only last svc paramerters
 	svcParams map[string]string
 }
 
-// NewLBWebServiceConfig contains fields that initiates WebServiceDescriber struct.
-type NewLBWebServiceConfig struct {
-	NewServiceConfig
-	EnableResources bool
-	DeployStore     DeployedEnvServicesLister
-}
-
 // NewLBWebServiceDescriber instantiates a load balanced service describer.
-func NewLBWebServiceDescriber(opt NewLBWebServiceConfig) (*LBWebServiceDescriber, error) {
+func NewLBWebServiceDescriber(opt NewServiceConfig) (*LBWebServiceDescriber, error) {
 	describer := &LBWebServiceDescriber{
-		app:             opt.App,
-		svc:             opt.Svc,
-		enableResources: opt.EnableResources,
-		store:           opt.DeployStore,
-		svcDescriber:    make(map[string]ecsSvcDescriber),
-		envDescriber:    make(map[string]envDescriber),
+		ecsServiceDescriber: &ecsServiceDescriber{
+			app:               opt.App,
+			svc:               opt.Svc,
+			enableResources:   opt.EnableResources,
+			store:             opt.DeployStore,
+			svcStackDescriber: make(map[string]ecsStackDescriber),
+		},
+		envDescriber: make(map[string]envDescriber),
 	}
-	describer.initDescriber = func(env string) error {
-		if _, ok := describer.svcDescriber[env]; ok {
+	describer.initDescribers = func(env string) error {
+		if _, ok := describer.svcStackDescriber[env]; ok {
 			return nil
 		}
 		svcDescr, err := NewServiceDescriber(NewServiceConfig{
@@ -114,7 +67,7 @@ func NewLBWebServiceDescriber(opt NewLBWebServiceConfig) (*LBWebServiceDescriber
 		if err != nil {
 			return err
 		}
-		describer.svcDescriber[env] = svcDescr
+		describer.svcStackDescriber[env] = svcDescr
 		envDescr, err := NewEnvDescriber(NewEnvDescriberConfig{
 			App:         opt.App,
 			Env:         env,
@@ -142,7 +95,7 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 	var envVars []*containerEnvVar
 	var secrets []*secret
 	for _, env := range environments {
-		err := d.initDescriber(env)
+		err := d.initDescribers(env)
 		if err != nil {
 			return nil, err
 		}
@@ -172,12 +125,12 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 			Port:     d.svcParams[cfnstack.LBWebServiceContainerPortParamKey],
 			Endpoint: endpoint,
 		}, env)
-		webSvcEnvVars, err := d.svcDescriber[env].EnvVars()
+		webSvcEnvVars, err := d.svcStackDescriber[env].EnvVars()
 		if err != nil {
 			return nil, fmt.Errorf("retrieve environment variables: %w", err)
 		}
 		envVars = append(envVars, flattenContainerEnvVars(env, webSvcEnvVars)...)
-		webSvcSecrets, err := d.svcDescriber[env].Secrets()
+		webSvcSecrets, err := d.svcStackDescriber[env].Secrets()
 		if err != nil {
 			return nil, fmt.Errorf("retrieve secrets: %w", err)
 		}
@@ -186,11 +139,11 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 	resources := make(map[string][]*stack.Resource)
 	if d.enableResources {
 		for _, env := range environments {
-			err := d.initDescriber(env)
+			err := d.initDescribers(env)
 			if err != nil {
 				return nil, err
 			}
-			stackResources, err := d.svcDescriber[env].ServiceStackResources()
+			stackResources, err := d.svcStackDescriber[env].ServiceStackResources()
 			if err != nil {
 				return nil, fmt.Errorf("retrieve service resources: %w", err)
 			}
@@ -213,50 +166,6 @@ func (d *LBWebServiceDescriber) Describe() (HumanJSONStringer, error) {
 	}, nil
 }
 
-// URI returns the LBWebServiceURI to identify this service uniquely given an environment name.
-func (d *LBWebServiceDescriber) URI(envName string) (string, error) {
-	err := d.initDescriber(envName)
-	if err != nil {
-		return "", err
-	}
-
-	envParams, err := d.envDescriber[envName].Params()
-	if err != nil {
-		return "", fmt.Errorf("get stack parameters for environment %s: %w", envName, err)
-	}
-	envOutputs, err := d.envDescriber[envName].Outputs()
-	if err != nil {
-		return "", fmt.Errorf("get stack outputs for environment %s: %w", envName, err)
-	}
-	svcParams, err := d.svcDescriber[envName].Params()
-	if err != nil {
-		return "", fmt.Errorf("get stack parameters for service %s: %w", d.svc, err)
-	}
-
-	uri := &LBWebServiceURI{
-		DNSNames: []string{envOutputs[envOutputPublicLoadBalancerDNSName]},
-		Path:     svcParams[cfnstack.LBWebServiceRulePathParamKey],
-	}
-	_, isHTTPS := envOutputs[envOutputSubdomain]
-	if isHTTPS {
-		dnsName := fmt.Sprintf("%s.%s", d.svc, envOutputs[envOutputSubdomain])
-		uri.DNSNames = []string{dnsName}
-		uri.HTTPS = true
-	}
-	aliases := envParams[cfnstack.EnvParamAliasesKey]
-	if aliases != "" {
-		value := make(map[string][]string)
-		if err := json.Unmarshal([]byte(aliases), &value); err != nil {
-			return "", err
-		}
-		if value[d.svc] != nil {
-			uri.DNSNames = value[d.svc]
-		}
-	}
-	d.svcParams = svcParams
-	return uri.String(), nil
-}
-
 type secret struct {
 	Name        string `json:"name"`
 	Container   string `json:"container"`
