@@ -4,10 +4,7 @@
 package manifest
 
 import (
-	"fmt"
-
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/copilot-cli/internal/pkg/exec"
 	"github.com/aws/copilot-cli/internal/pkg/template"
 	"github.com/imdario/mergo"
 )
@@ -40,19 +37,19 @@ type RequestDrivenWebServiceHttpConfig struct {
 	Alias                    *string                 `yaml:"alias"`
 }
 
+// AppRunnerInstanceConfig contains the instance configuration properties for an App Runner service.
+type AppRunnerInstanceConfig struct {
+	CPU      *int                  `yaml:"cpu"`
+	Memory   *int                  `yaml:"memory"`
+	Platform *PlatformArgsOrString `yaml:"platform,omitempty"`
+}
+
 // RequestDrivenWebServiceProps contains properties for creating a new request-driven web service manifest.
 type RequestDrivenWebServiceProps struct {
 	*WorkloadProps
 	Port uint16
 }
 
-// AppRunnerInstanceConfig contains the instance configuration properties for an App Runner service.
-type AppRunnerInstanceConfig struct {
-	CPU      *int    `yaml:"cpu"`
-	Memory   *int    `yaml:"memory"`
-	Platform *string `yaml:"platform,omitempty"`
-}
-
 // NewRequestDrivenWebService creates a new Request-Driven Web Service manifest with default values.
 func NewRequestDrivenWebService(props *RequestDrivenWebServiceProps) *RequestDrivenWebService {
 	svc := newDefaultRequestDrivenWebService()
@@ -64,6 +61,69 @@ func NewRequestDrivenWebService(props *RequestDrivenWebServiceProps) *RequestDri
 	return svc
 }
 
+// MarshalBinary serializes the manifest object into a binary YAML document.
+// Implements the encoding.BinaryMarshaler interface.
+func (s *RequestDrivenWebService) MarshalBinary() ([]byte, error) {
+	content, err := s.parser.Parse(requestDrivenWebSvcManifestPath, *s)
+	if err != nil {
+		return nil, err
+	}
+	return content.Bytes(), nil
+}
+
+// Port returns the exposed the exposed port in the manifest.
+// A RequestDrivenWebService always has a port exposed therefore the boolean is always true.
+func (s *RequestDrivenWebService) Port() (port uint16, ok bool) {
+	return aws.Uint16Value(s.ImageConfig.Port), true
+}
+
+// Publish returns the list of topics where notifications can be published.
+func (s *RequestDrivenWebService) Publish() []Topic {
+	if s.RequestDrivenWebServiceConfig.Publish == nil {
+		return nil
+	}
+	return s.RequestDrivenWebServiceConfig.Publish.Topics
+}
+
+// BuildRequired returns if the service requires building from the local Dockerfile.
+func (s *RequestDrivenWebService) BuildRequired() (bool, error) {
+	return requiresBuild(s.ImageConfig.Image)
+}
+
+// TaskPlatform returns the platform for the service.
+func (s *RequestDrivenWebService) TaskPlatform() (*string, error) {
+	if s.InstanceConfig.Platform == nil {
+		return nil, nil
+	}
+	return s.InstanceConfig.Platform.PlatformString, nil
+}
+
+// BuildArgs returns a docker.BuildArguments object given a ws root directory.
+func (s *RequestDrivenWebService) BuildArgs(wsRoot string) *DockerBuildArgs {
+	return s.ImageConfig.BuildConfig(wsRoot)
+}
+
+// ApplyEnv returns the service manifest with environment overrides.
+// If the environment passed in does not have any overrides then it returns itself.
+func (s RequestDrivenWebService) ApplyEnv(envName string) (WorkloadManifest, error) {
+	overrideConfig, ok := s.Environments[envName]
+	if !ok {
+		return &s, nil
+	}
+	// Apply overrides to the original service configuration.
+	for _, t := range defaultTransformers {
+		err := mergo.Merge(&s, RequestDrivenWebService{
+			RequestDrivenWebServiceConfig: *overrideConfig,
+		}, mergo.WithOverride, mergo.WithTransformers(t))
+		if err != nil {
+			return nil, err
+		}
+	}
+
+	s.Environments = nil
+	return &s, nil
+}
+
 // newDefaultRequestDrivenWebService returns an empty RequestDrivenWebService with only the default values set.
 func newDefaultRequestDrivenWebService() *RequestDrivenWebService {
 	return &RequestDrivenWebService{
@@ -79,50 +139,3 @@ func newDefaultRequestDrivenWebService() *RequestDrivenWebService {
 		},
 	}
 }
-
-// MarshalBinary serializes the manifest object into a binary YAML document.
-// Implements the encoding.BinaryMarshaler interface.
-func (s *RequestDrivenWebService) MarshalBinary() ([]byte, error) {
-	content, err := s.parser.Parse(requestDrivenWebSvcManifestPath, *s)
-	if err != nil {
-		return nil, err
-	}
-	return content.Bytes(), nil
-}
-
-// BuildRequired returns if the service requires building from the local Dockerfile.
-func (s *RequestDrivenWebService) BuildRequired() (bool, error) {
-	return requiresBuild(s.ImageConfig.Image)
-}
-
-// TaskPlatform returns the os/arch for the service.
-func (c *RequestDrivenWebService) TaskPlatform() (*string, error) {
-	if err := exec.ValidatePlatform(c.RequestDrivenWebServiceConfig.InstanceConfig.Platform); err != nil {
-		return nil, fmt.Errorf("validate platform: %w", err)
-	}
-	return c.RequestDrivenWebServiceConfig.InstanceConfig.Platform, nil
-}
-
-// BuildArgs returns a docker.BuildArguments object given a ws root directory.
-func (s *RequestDrivenWebService) BuildArgs(wsRoot string) *DockerBuildArgs {
-	return s.ImageConfig.BuildConfig(wsRoot)
-}
-
-// ApplyEnv returns the service manifest with environment overrides.
-// If the environment passed in does not have any overrides then it returns itself.
-func (s RequestDrivenWebService) ApplyEnv(envName string) (WorkloadManifest, error) {
-	overrideConfig, ok := s.Environments[envName]
-	if !ok {
-		return &s, nil
-	}
-	// Apply overrides to the original service configuration.
-	err := mergo.Merge(&s, RequestDrivenWebService{
-		RequestDrivenWebServiceConfig: *overrideConfig,
-	}, mergo.WithOverride, mergo.WithOverwriteWithEmptyValue, mergo.WithTransformers(workloadTransformer{}))
-
-	if err != nil {
-		return nil, err
-	}
-	s.Environments = nil
-	return &s, nil
-}
