@@ -140,7 +140,7 @@ func TestWorkerSvc_MarshalBinary(t *testing.T) {
 					Name:       "testers",
 					Dockerfile: "./testers/Dockerfile",
 				},
-				Topics: &[]TopicSubscription{
+				Topics: []TopicSubscription{
 					{
 						Name:    "testTopic",
 						Service: "service4TestTopic",
@@ -259,7 +259,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 				},
 			},
 			Subscribe: &SubscribeConfig{
-				Topics: &[]TopicSubscription{
+				Topics: []TopicSubscription{
 					{
 						Name:    "topicName",
 						Service: "bestService",
@@ -299,7 +299,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					},
 				},
 				Subscribe: &SubscribeConfig{
-					Topics: &[]TopicSubscription{
+					Topics: []TopicSubscription{
 						{
 							Name:    "topicName2",
 							Service: "bestService2",
@@ -418,7 +418,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
 			Subscribe: &SubscribeConfig{
-				Topics: &[]TopicSubscription{
+				Topics: []TopicSubscription{
 					{
 						Name:    "name",
 						Service: "svc",
@@ -427,7 +427,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							Delay:      &duration111Seconds,
 							Timeout:    &duration111Seconds,
 							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 						},
 					},
 				},
@@ -450,7 +449,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
 				Subscribe: &SubscribeConfig{
-					Topics: &[]TopicSubscription{
+					Topics: []TopicSubscription{
 						{
 							Name:    "name",
 							Service: "svc",
@@ -459,7 +458,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 								Delay:      &duration111Seconds,
 								Timeout:    &duration111Seconds,
 								DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 							},
 						},
 					},
@@ -474,7 +472,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
 			Subscribe: &SubscribeConfig{
-				Topics: &[]TopicSubscription{
+				Topics: []TopicSubscription{
 					{
 						Name:    "name",
 						Service: "svc",
@@ -483,7 +481,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							Delay:      &duration111Seconds,
 							Timeout:    &duration111Seconds,
 							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 						},
 					},
 				},
@@ -508,7 +505,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
 				Subscribe: &SubscribeConfig{
-					Topics: &[]TopicSubscription{
+					Topics: []TopicSubscription{
 						{
 							Name:    "name",
 							Service: "svc",
@@ -517,7 +514,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 								Delay:      &duration111Seconds,
 								Timeout:    &duration111Seconds,
 								DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 							},
 						},
 					},
@@ -532,7 +528,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
 			Subscribe: &SubscribeConfig{
-				Topics: &[]TopicSubscription{
+				Topics: []TopicSubscription{
 					{
 						Name:    "name",
 						Service: "svc",
@@ -541,7 +537,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							Delay:      &duration111Seconds,
 							Timeout:    &duration111Seconds,
 							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 						},
 					},
 				},
@@ -562,13 +557,13 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 		},
 		WorkerServiceConfig: WorkerServiceConfig{
 			Subscribe: &SubscribeConfig{
-				Topics: &[]TopicSubscription{},
+				Topics: []TopicSubscription{},
 			},
 		},
 		Environments: map[string]*WorkerServiceConfig{
 			"test-sub": {
 				Subscribe: &SubscribeConfig{
-					Topics: &[]TopicSubscription{
+					Topics: []TopicSubscription{
 						{
 							Name:    "name",
 							Service: "svc",
@@ -577,7 +572,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 								Delay:      &duration111Seconds,
 								Timeout:    &duration111Seconds,
 								DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-								FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 							},
 						},
 					},
@@ -603,7 +597,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						Delay:      &duration111Seconds,
 						Timeout:    &duration111Seconds,
 						DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 					},
 				},
 			},
@@ -621,7 +614,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 					Delay:      &duration111Seconds,
 					Timeout:    &duration111Seconds,
 					DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-					FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 				},
 			},
 		},
@@ -651,7 +643,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						Delay:      &duration111Seconds,
 						Timeout:    &duration111Seconds,
 						DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-						FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 					},
 				},
 			},
@@ -731,7 +722,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						},
 					},
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "topicName2",
 								Service: "bestService2",
@@ -830,7 +821,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "name",
 								Service: "svc",
@@ -839,7 +830,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 									Delay:      &duration111Seconds,
 									Timeout:    &duration111Seconds,
 									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-									FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 								},
 							},
 						},
@@ -859,7 +849,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "name",
 								Service: "svc",
@@ -868,7 +858,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 									Delay:      &duration111Seconds,
 									Timeout:    &duration111Seconds,
 									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-									FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 								},
 							},
 						},
@@ -891,7 +880,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						Image: Image{},
 					},
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "name",
 								Service: "svc",
@@ -900,7 +889,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 									Delay:      &duration111Seconds,
 									Timeout:    &duration111Seconds,
 									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-									FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 								},
 							},
 						},
@@ -920,7 +908,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "name",
 								Service: "svc",
@@ -929,7 +917,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 									Delay:      &duration111Seconds,
 									Timeout:    &duration111Seconds,
 									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-									FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 								},
 							},
 						},
@@ -949,7 +936,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 				},
 				WorkerServiceConfig: WorkerServiceConfig{
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "name",
 								Service: "svc",
@@ -958,7 +945,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 									Delay:      &duration111Seconds,
 									Timeout:    &duration111Seconds,
 									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-									FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 								},
 							},
 						},
@@ -981,7 +967,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 						Image: Image{},
 					},
 					Subscribe: &SubscribeConfig{
-						Topics: &[]TopicSubscription{
+						Topics: []TopicSubscription{
 							{
 								Name:    "name",
 								Service: "svc",
@@ -990,7 +976,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 									Delay:      &duration111Seconds,
 									Timeout:    &duration111Seconds,
 									DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-									FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 								},
 							},
 						},
@@ -1015,7 +1000,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							Delay:      &duration111Seconds,
 							Timeout:    &duration111Seconds,
 							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 						},
 					},
 				},
@@ -1038,7 +1022,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							Delay:      &duration111Seconds,
 							Timeout:    &duration111Seconds,
 							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 						},
 					},
 				},
@@ -1046,7 +1029,7 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 
 			original: &mockWorkerServiceWithSubscribeQueueNilOverride,
 		},
-		"with empty subscribe queue overriden by full subscribe queue": {
+		"with empty subscribe queue overridden by full subscribe queue": {
 			svc:       &mockWorkerServiceWithSubscribeQueueEmptyOverride,
 			inEnvName: "test-sub",
 			wanted: &WorkerService{
@@ -1064,7 +1047,6 @@ func TestWorkerSvc_ApplyEnv(t *testing.T) {
 							Delay:      &duration111Seconds,
 							Timeout:    &duration111Seconds,
 							DeadLetter: &DeadLetterQueue{Tries: aws.Uint16(10)},
-							FIFO:       &FIFOOrBool{Enabled: aws.Bool(true)},
 						},
 					},
 				},
@@ -1246,60 +1228,56 @@ func TestWorkerSvc_ApplyEnv_CountOverrides(t *testing.T) {
 	}
 }
 
-type testFIFO struct {
-	FIFO *FIFOOrBool `yaml:"fifo"`
-}
-
-func Test_UnmarshalFifo(t *testing.T) {
+func TestWorkerSvc_Subscriptions(t *testing.T) {
 	testCases := map[string]struct {
-		manifest []byte
-		want     testFIFO
-		wantErr  error
+		inSubscription SubscribeConfig
+		expected       []TopicSubscription
 	}{
-		"fifo specified": {
-			manifest: []byte(`
-fifo:
-  high_throughput: true`),
-			want: testFIFO{
-				FIFO: &FIFOOrBool{
-					FIFO: FIFOQueue{
-						HighThroughput: aws.Bool(true),
+		"subscription specified": {
+			inSubscription: SubscribeConfig{
+				Topics: []TopicSubscription{
+					{
+						Name:    "orders",
+						Service: "database",
+					},
+					{
+						Name:    "events",
+						Service: "api",
 					},
 				},
+				Queue: &SQSQueue{
+					Retention: durationPointer(4 * 24 * time.Hour),
+				},
 			},
-		},
-		"enabled": {
-			manifest: []byte(`
-fifo: true`),
-			want: testFIFO{
-				FIFO: &FIFOOrBool{
-					Enabled: aws.Bool(true),
+			expected: []TopicSubscription{
+				{
+					Name:    "orders",
+					Service: "database",
+				},
+				{
+					Name:    "events",
+					Service: "api",
 				},
 			},
 		},
-		"invalid input": {
-			manifest: []byte(`
-fifo: xyz`),
-			wantErr: errUnmarshalFIFO,
+		"no topics": {
+			inSubscription: SubscribeConfig{},
+			expected:       nil,
 		},
 	}
 	for name, tc := range testCases {
+		// GIVEN
+		svc := WorkerService{
+			WorkerServiceConfig: WorkerServiceConfig{
+				Subscribe: &tc.inSubscription,
+			},
+		}
 		t.Run(name, func(t *testing.T) {
-			// GIVEN
-			v := testFIFO{
-				FIFO: &FIFOOrBool{},
-			}
-
 			// WHEN
-			err := yaml.Unmarshal(tc.manifest, &v)
+			actual := svc.Subscriptions()
+
 			// THEN
-			if tc.wantErr == nil {
-				require.NoError(t, err)
-				require.Equal(t, tc.want.FIFO.Enabled, v.FIFO.Enabled)
-				require.Equal(t, tc.want.FIFO.FIFO.HighThroughput, v.FIFO.FIFO.HighThroughput)
-			} else {
-				require.EqualError(t, err, tc.wantErr.Error())
-			}
+			require.Equal(t, tc.expected, actual)
 		})
 	}
 }
