@@ -285,10 +285,9 @@ func TestGenerateSNSJSON(t *testing.T) {
 
 func TestGenerateQueueURIJSON(t *testing.T) {
 	testCases := map[string]struct {
-		in               []*TopicSubscription
-		wanted           string
-		wantedSubstring  string
-		wantedSubstring2 string
+		in              []*TopicSubscription
+		wanted          string
+		wantedSubstring string
 	}{
 		"JSON should render correctly": {
 			in: []*TopicSubscription{
@@ -300,8 +299,7 @@ func TestGenerateQueueURIJSON(t *testing.T) {
 					},
 				},
 			},
-			wantedSubstring:  `"eventsQueue":"${mainURL}"`,
-			wantedSubstring2: `"bestsvcTestsEventsQueue":"${bestsvctestsURL}"`,
+			wantedSubstring: `"bestsvcTestsEventsQueue":"${bestsvctestsURL}"`,
 		},
 		"Topics with no names show empty but main queue still populates": {
 			in: []*TopicSubscription{
@@ -309,11 +307,7 @@ func TestGenerateQueueURIJSON(t *testing.T) {
 					Service: aws.String("bestSvc"),
 				},
 			},
-			wanted: `{"eventsQueue":"${mainURL}"}`,
-		},
-		"nil list of arguments should render with main queue": {
-			in:     []*TopicSubscription{},
-			wanted: `{"eventsQueue":"${mainURL}"}`,
+			wanted: `{}`,
 		},
 	}
 
@@ -323,7 +317,6 @@ func TestGenerateQueueURIJSON(t *testing.T) {
 				require.Equal(t, generateQueueURIJSON(tc.in), tc.wanted)
 			} else {
 				require.Contains(t, generateQueueURIJSON(tc.in), tc.wantedSubstring)
-				require.Contains(t, generateQueueURIJSON(tc.in), tc.wantedSubstring2)
 			}
 		})
 	}
