@@ -7,7 +7,6 @@ import (
 	"fmt"
 	"testing"
 
-	"github.com/gobuffalo/packd"
 	"github.com/stretchr/testify/require"
 	"gopkg.in/yaml.v3"
 )
@@ -17,45 +16,45 @@ func TestTemplate_ParseSvc(t *testing.T) {
 		testSvcName = "backend"
 	)
 	testCases := map[string]struct {
-		mockDependencies func(t *Template)
-		wantedContent    string
-		wantedErr        error
+		fs            func() map[string][]byte
+		wantedContent string
+		wantedErr     error
 	}{
 		"renders all common templates": {
-			mockDependencies: func(t *Template) {
-				mockBox := packd.NewMemoryBox()
+			fs: func() map[string][]byte {
 				var baseContent string
 				for _, name := range partialsWorkloadCFTemplateNames {
 					baseContent += fmt.Sprintf(`{{include "%s" . | indent 2}}`+"\n", name)
 				}
-				mockBox.AddString("workloads/services/backend/cf.yml", baseContent)
-				mockBox.AddString("workloads/partials/cf/loggroup.yml", "loggroup")
-				mockBox.AddString("workloads/partials/cf/envvars.yml", "envvars")
-				mockBox.AddString("workloads/partials/cf/secrets.yml", "secrets")
-				mockBox.AddString("workloads/partials/cf/executionrole.yml", "executionrole")
-				mockBox.AddString("workloads/partials/cf/taskrole.yml", "taskrole")
-				mockBox.AddString("workloads/partials/cf/workload-container.yml", "workload-container")
-				mockBox.AddString("workloads/partials/cf/fargate-taskdef-base-properties.yml", "fargate-taskdef-base-properties")
-				mockBox.AddString("workloads/partials/cf/service-base-properties.yml", "service-base-properties")
-				mockBox.AddString("workloads/partials/cf/servicediscovery.yml", "servicediscovery")
-				mockBox.AddString("workloads/partials/cf/addons.yml", "addons")
-				mockBox.AddString("workloads/partials/cf/sidecars.yml", "sidecars")
-				mockBox.AddString("workloads/partials/cf/logconfig.yml", "logconfig")
-				mockBox.AddString("workloads/partials/cf/autoscaling.yml", "autoscaling")
-				mockBox.AddString("workloads/partials/cf/state-machine-definition.json.yml", "state-machine-definition")
-				mockBox.AddString("workloads/partials/cf/eventrule.yml", "eventrule")
-				mockBox.AddString("workloads/partials/cf/state-machine.yml", "state-machine")
-				mockBox.AddString("workloads/partials/cf/efs-access-point.yml", "efs-access-point")
-				mockBox.AddString("workloads/partials/cf/env-controller.yml", "env-controller")
-				mockBox.AddString("workloads/partials/cf/mount-points.yml", "mount-points")
-				mockBox.AddString("workloads/partials/cf/volumes.yml", "volumes")
-				mockBox.AddString("workloads/partials/cf/image-overrides.yml", "image-overrides")
-				mockBox.AddString("workloads/partials/cf/instancerole.yml", "instancerole")
-				mockBox.AddString("workloads/partials/cf/accessrole.yml", "accessrole")
-				mockBox.AddString("workloads/partials/cf/publish.yml", "publish")
-				mockBox.AddString("workloads/partials/cf/subscribe.yml", "subscribe")
 
-				t.box = mockBox
+				return map[string][]byte{
+					"templates/workloads/services/backend/cf.yml":                         []byte(baseContent),
+					"templates/workloads/partials/cf/loggroup.yml":                        []byte("loggroup"),
+					"templates/workloads/partials/cf/envvars.yml":                         []byte("envvars"),
+					"templates/workloads/partials/cf/secrets.yml":                         []byte("secrets"),
+					"templates/workloads/partials/cf/executionrole.yml":                   []byte("executionrole"),
+					"templates/workloads/partials/cf/taskrole.yml":                        []byte("taskrole"),
+					"templates/workloads/partials/cf/workload-container.yml":              []byte("workload-container"),
+					"templates/workloads/partials/cf/fargate-taskdef-base-properties.yml": []byte("fargate-taskdef-base-properties"),
+					"templates/workloads/partials/cf/service-base-properties.yml":         []byte("service-base-properties"),
+					"templates/workloads/partials/cf/servicediscovery.yml":                []byte("servicediscovery"),
+					"templates/workloads/partials/cf/addons.yml":                          []byte("addons"),
+					"templates/workloads/partials/cf/sidecars.yml":                        []byte("sidecars"),
+					"templates/workloads/partials/cf/logconfig.yml":                       []byte("logconfig"),
+					"templates/workloads/partials/cf/autoscaling.yml":                     []byte("autoscaling"),
+					"templates/workloads/partials/cf/state-machine-definition.json.yml":   []byte("state-machine-definition"),
+					"templates/workloads/partials/cf/eventrule.yml":                       []byte("eventrule"),
+					"templates/workloads/partials/cf/state-machine.yml":                   []byte("state-machine"),
+					"templates/workloads/partials/cf/efs-access-point.yml":                []byte("efs-access-point"),
+					"templates/workloads/partials/cf/env-controller.yml":                  []byte("env-controller"),
+					"templates/workloads/partials/cf/mount-points.yml":                    []byte("mount-points"),
+					"templates/workloads/partials/cf/volumes.yml":                         []byte("volumes"),
+					"templates/workloads/partials/cf/image-overrides.yml":                 []byte("image-overrides"),
+					"templates/workloads/partials/cf/instancerole.yml":                    []byte("instancerole"),
+					"templates/workloads/partials/cf/accessrole.yml":                      []byte("accessrole"),
+					"templates/workloads/partials/cf/publish.yml":                         []byte("publish"),
+					"templates/workloads/partials/cf/subscribe.yml":                       []byte("subscribe"),
+				}
 			},
 			wantedContent: `  loggroup
   envvars
@@ -89,8 +88,9 @@ func TestTemplate_ParseSvc(t *testing.T) {
 	for name, tc := range testCases {
 		t.Run(name, func(t *testing.T) {
 			// GIVEN
-			tpl := &Template{}
-			tc.mockDependencies(tpl)
+			tpl := &Template{
+				fs: &mockReadFileFS{tc.fs()},
+			}
 
 			// WHEN
 			c, err := tpl.parseSvc(testSvcName, nil)
@@ -164,14 +164,14 @@ func TestTemplate_ParseNetwork(t *testing.T) {
 		"should render AWS VPC configuration for public subnets by default": {
 			input: nil,
 			wantedNetworkConfig: `
-  AwsvpcConfiguration:
-    AssignPublicIp: ENABLED
-    Subnets:
-      Fn::Split:
-        - ','
-        - Fn::ImportValue: !Sub '${AppName}-${EnvName}-PublicSubnets'
-    SecurityGroups:
-      - Fn::ImportValue: !Sub '${AppName}-${EnvName}-EnvironmentSecurityGroup'
+ AwsvpcConfiguration:
+   AssignPublicIp: ENABLED
+   Subnets:
+     Fn::Split:
+       - ','
+       - Fn::ImportValue: !Sub '${AppName}-${EnvName}-PublicSubnets'
+   SecurityGroups:
+     - Fn::ImportValue: !Sub '${AppName}-${EnvName}-EnvironmentSecurityGroup'
 `,
 		},
 		"should render AWS VPC configuration for private subnets": {
@@ -180,14 +180,14 @@ func TestTemplate_ParseNetwork(t *testing.T) {
 				SubnetsType:    "PrivateSubnets",
 			},
 			wantedNetworkConfig: `
-  AwsvpcConfiguration:
-    AssignPublicIp: DISABLED
-    Subnets:
-      Fn::Split:
-        - ','
-        - Fn::ImportValue: !Sub '${AppName}-${EnvName}-PrivateSubnets'
-    SecurityGroups:
-      - Fn::ImportValue: !Sub '${AppName}-${EnvName}-EnvironmentSecurityGroup'
+ AwsvpcConfiguration:
+   AssignPublicIp: DISABLED
+   Subnets:
+     Fn::Split:
+       - ','
+       - Fn::ImportValue: !Sub '${AppName}-${EnvName}-PrivateSubnets'
+   SecurityGroups:
+     - Fn::ImportValue: !Sub '${AppName}-${EnvName}-EnvironmentSecurityGroup'
 `,
 		},
 		"should render AWS VPC configuration for private subnets with security groups": {
@@ -200,16 +200,16 @@ func TestTemplate_ParseNetwork(t *testing.T) {
 				},
 			},
 			wantedNetworkConfig: `
-  AwsvpcConfiguration:
-    AssignPublicIp: DISABLED
-    Subnets:
-      Fn::Split:
-        - ','
-        - Fn::ImportValue: !Sub '${AppName}-${EnvName}-PrivateSubnets'
-    SecurityGroups:
-      - Fn::ImportValue: !Sub '${AppName}-${EnvName}-EnvironmentSecurityGroup'
-      - "sg-1bcf1d5b"
-      - "sg-asdasdas"
+ AwsvpcConfiguration:
+   AssignPublicIp: DISABLED
+   Subnets:
+     Fn::Split:
+       - ','
+       - Fn::ImportValue: !Sub '${AppName}-${EnvName}-PrivateSubnets'
+   SecurityGroups:
+     - Fn::ImportValue: !Sub '${AppName}-${EnvName}-EnvironmentSecurityGroup'
+     - "sg-1bcf1d5b"
+     - "sg-asdasdas"
 `,
 		},
 	}
